@@ -1,9 +1,11 @@
 import datetime
 import os.path as osp
 import shutil
+import socket
 
 from loguru import logger
 
+# https://docs.python.org/3/library/datetime.html#strftime-and-strptime-behavior
 TIME_PARTTERN = "%Y-%m-%dT%H:%M:%S"
 
 
@@ -25,14 +27,17 @@ def extract_time(run):
     return duration, run2now
 
 
-def delete_run(run, delete=True):
+def delete_run(run, delete=True, is_all=False):
+    # FIXME: should be a better approach to get hostname
+    if not is_all and run.config["host"] != socket.gethostname():
+        logger.info(f"skip {run.config['host']} {run.name}\t{run.url}")
     delete_info = f"{run.name}\t{run.url}"
     cfg = run.config
-    if "hyd_path" in cfg:
-        if osp.exists(cfg["hyd_path"]):
+    if "run_path" in cfg:
+        if osp.exists(cfg["run_path"]):
             if delete:
-                shutil.rmtree(cfg["hyd_path"], ignore_errors=True)
-            delete_info += f"\n\t{cfg['hyd_path']}"
+                shutil.rmtree(cfg["run_path"], ignore_errors=True)
+            delete_info += f"\n\t{cfg['run_path']}"
     logger.info(delete_info)
     if delete:
         run.delete()
